import 'package:flutter/material.dart';
import 'package:video_player/video_player.dart';

class VideoControlsOverlay extends StatelessWidget {
  final VideoPlayerController controller;
  const VideoControlsOverlay({super.key, required this.controller});

  @override
  Widget build(BuildContext context) {
    return Stack(
      alignment: Alignment.center,
      children: [
        Center(
          child: Row(
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              _ControlButton(Icons.replay_10, () {
                controller.seekTo(
                  controller.value.position - Duration(seconds: 10),
                );
              }),
              SizedBox(width: 32),
              _ControlButton(
                controller.value.isPlaying ? Icons.pause : Icons.play_arrow,
                () {
                  controller.value.isPlaying
                      ? controller.pause()
                      : controller.play();
                },
                size: 64,
              ),
              SizedBox(width: 32),
              _ControlButton(Icons.forward_10, () {
                controller.seekTo(
                  controller.value.position + Duration(seconds: 10),
                );
              }),
            ],
          ),
        ),
        _ProgressIndicator(controller: controller),
      ],
    );
  }
}

class _ControlButton extends StatelessWidget {
  final IconData icon;
  final VoidCallback onPressed;
  final double size;

  const _ControlButton(this.icon, this.onPressed, {this.size = 24});

  @override
  Widget build(BuildContext context) {
    return Container(
      decoration: BoxDecoration(
        shape: BoxShape.circle,
        color: Colors.black.withValues(alpha: 0.4),
      ),
      child: IconButton(
        icon: Icon(icon, color: Colors.white, size: size),
        onPressed: onPressed,
      ),
    );
  }
}

class _ProgressIndicator extends StatelessWidget {
  final VideoPlayerController controller;
  const _ProgressIndicator({required this.controller});

  @override
  Widget build(BuildContext context) {
    return Align(
      alignment: Alignment.bottomCenter,
      child: Stack(
        clipBehavior: Clip.none,
        children: [
          Container(
            height: 20,
            alignment: Alignment.bottomCenter,
            color: Colors.transparent,
            child: VideoProgressIndicator(
              controller,
              allowScrubbing: true,
              colors: VideoProgressColors(
                playedColor: Colors.red,
                backgroundColor: Colors.grey,
                bufferedColor: Colors.white54,
              ),
            ),
          ),
          Positioned(
            left:
                (controller.value.position.inMilliseconds /
                        controller.value.duration.inMilliseconds) *
                    MediaQuery.of(context).size.width -
                6,
            bottom: -4,
            child: Container(
              width: 12,
              height: 12,
              decoration: BoxDecoration(
                shape: BoxShape.circle,
                color: Colors.red,
                border: Border.all(color: Colors.red, width: 2),
              ),
            ),
          ),
          Positioned(
            left: 16,
            bottom: 10,
            child: Text(
              '${_formatDuration(controller.value.position)} / ${_formatDuration(controller.value.duration)}',
              style: TextStyle(color: Colors.white),
            ),
          ),
        ],
      ),
    );
  }

  String _formatDuration(Duration duration) {
    String twoDigits(int n) => n.toString().padLeft(2, '0');
    final minutes = twoDigits(duration.inMinutes.remainder(60));
    final seconds = twoDigits(duration.inSeconds.remainder(60));
    return "$minutes:$seconds";
  }
}
